@@ -1,7 +1,7 @@
 /*  api.c
  *
  *  Copyright (C) 2017 Jakob Kreuze <jakob@memeware.net>
- *  Copyright (C) 2017-2024 Toxic All Rights Reserved.
+ *  Copyright (C) 2017-2026 Toxic All Rights Reserved.
  *
  *  This file is part of Toxic. Toxic is free software licensed
  *  under the GNU General Public License 3.0.
@@ -45,7 +45,13 @@ void api_display(const char *const msg)
 
 FriendsList api_get_friendslist(void)
 {
-    return Friends;
+    if (user_toxic == NULL || user_toxic->friends == NULL) {
+        return (FriendsList) {
+            0
+        };
+    }
+
+    return *user_toxic->friends;
 }
 
 char *api_get_nick(void)
@@ -174,8 +180,8 @@ void cmd_run(WINDOW *window, ToxWindow *self, Toxic *toxic, int argc, char (*arg
 
 void invoke_autoruns(ToxWindow *self, const char *autorun_path)
 {
-    char abspath_buf[PATH_MAX + 256];
-    char err_buf[PATH_MAX + 128];
+    char abspath_buf[TOXIC_MAX_PATH_LENGTH + 256];
+    char err_buf[TOXIC_MAX_PATH_LENGTH + 128];
 
     if (autorun_path == NULL) {
         return;
