@@ -1,6 +1,6 @@
 /*  audio_call.h
  *
- *  Copyright (C) 2014-2024 Toxic All Rights Reserved.
+ *  Copyright (C) 2014-2026 Toxic All Rights Reserved.
  *
  *  This file is part of Toxic. Toxic is free software licensed
  *  under the GNU General Public License 3.0.
@@ -42,6 +42,14 @@ typedef enum CallStatus {
     cs_Active
 } CallStatus;
 
+typedef struct AudioTransmissionContext {
+    ToxAV *av;
+    uint32_t friend_number;
+    int32_t audio_frame_duration;
+    uint32_t audio_sample_rate;
+    uint8_t audio_channels;
+} AudioTransmissionContext;
+
 typedef struct Call {
     CallStatus status;
     uint32_t state; /* ToxAV call state, valid when `status == cs_Active` */
@@ -51,6 +59,8 @@ typedef struct Call {
     uint32_t vin_idx, vout_idx; /* Video device index, or -1 if not open */
     uint32_t video_width, video_height;
     uint32_t video_bit_rate; /* Bit rate for sending video; 0 for no video */
+
+    AudioTransmissionContext audio_tx_ctx;
 } Call;
 
 struct CallControl {
@@ -59,9 +69,7 @@ struct CallControl {
     VideoError video_errors;
 #endif /* VIDEO */
 
-    ToxAV *av;
-
-    Call *calls;
+    Call **calls;
     uint32_t max_calls;
 
     bool audio_enabled;
@@ -77,13 +85,11 @@ struct CallControl {
     uint32_t default_video_bit_rate;
 };
 
-extern struct CallControl CallControl;
-
 /* You will have to pass pointer to first member of 'windows' declared in windows.c */
 ToxAV *init_audio(Toxic *toxic);
-void terminate_audio(ToxAV *av);
+void terminate_audio(ToxAV *av, struct CallControl *cc);
 
-bool init_call(Call *call);
+bool init_call(struct CallControl *cc, Call *call, uint32_t friend_number);
 
 void place_call(ToxWindow *self, Toxic *toxic);
 void stop_current_call(ToxWindow *self, Toxic *toxic);
@@ -94,7 +100,7 @@ void stop_current_call(ToxWindow *self, Toxic *toxic);
  *
  * Returns true on success.
  */
-bool init_friend_AV(uint32_t index);
-void del_friend_AV(uint32_t index);
+bool init_friend_AV(struct CallControl *cc, uint32_t index);
+void del_friend_AV(struct CallControl *cc, uint32_t index);
 
 #endif /* AUDIO_CALL_H */
