@@ -1,23 +1,9 @@
 /*  autocomplete.c
  *
+ *  Copyright (C) 2014-2026 Toxic All Rights Reserved.
  *
- *  Copyright (C) 2024 Toxic All Rights Reserved.
- *
- *  This file is part of Toxic.
- *
- *  Toxic is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version.
- *
- *  Toxic is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with Toxic.  If not, see <http://www.gnu.org/licenses/>.
- *
+ *  This file is part of Toxic. Toxic is free software licensed
+ *  under the GNU General Public License 3.0.
  */
 
 #include "autocomplete.h"
@@ -50,7 +36,7 @@ static void print_ac_matches(ToxWindow *self, Toxic *toxic, char **list, size_t
         line_info_add(self, toxic->c_config, false, NULL, NULL, SYS_MSG, 0, 0, "%s", list[i]);
     }
 
-    line_info_add(self, toxic->c_config, false, NULL, NULL, SYS_MSG, 0, 0, "");
+    line_info_add(self, toxic->c_config, false, NULL, NULL, SYS_MSG, 0, 0, " ");
 }
 
 /* puts match in match buffer. if more than one match, add first n chars that are identical.
@@ -122,6 +108,10 @@ static int complete_line_helper(ToxWindow *self, Toxic *toxic, const char *const
         return -1;
     }
 
+    if (ubuf[0] == '/' && ubuf[1] == '\0') {
+        return -1;
+    }
+
     if (out != NULL) {
         snprintf(out, MAX_STR_SIZE, "%s", ubuf);
     }
@@ -135,7 +125,7 @@ static int complete_line_helper(ToxWindow *self, Toxic *toxic, const char *const
     char *sub = calloc(1, strlen(ubuf) + 1);
 
     if (sub == NULL) {
-        exit_toxic_err("failed in complete_line_helper", FATALERR_MEMORY);
+        return -1;
     }
 
     if (!s && !dir_search) {
@@ -162,7 +152,7 @@ static int complete_line_helper(ToxWindow *self, Toxic *toxic, const char *const
         return 0;
     }
 
-    int s_len = strlen(sub);
+    const int s_len = strlen(sub);
     size_t n_matches = 0;
 
     char **matches = (char **) malloc_ptr_array(n_items, MAX_STR_SIZE);
@@ -191,7 +181,8 @@ static int complete_line_helper(ToxWindow *self, Toxic *toxic, const char *const
     }
 
     char match[MAX_STR_SIZE];
-    size_t match_len = get_str_match(self, match, sizeof(match), (const char *const *) matches, n_matches, MAX_STR_SIZE);
+    const size_t match_len = get_str_match(self, match, sizeof(match), (const char *const *) matches,
+                                           n_matches, MAX_STR_SIZE);
 
     free_ptr_array((void **) matches);
 
@@ -210,8 +201,8 @@ static int complete_line_helper(ToxWindow *self, Toxic *toxic, const char *const
     }
 
     /* put match in correct spot in buf and append endchars */
-    int n_endchrs = strlen(endchrs);
-    int strt = ctx->pos - s_len;
+    const int n_endchrs = strlen(endchrs);
+    const int strt = ctx->pos - s_len;
     int diff = match_len - s_len + n_endchrs;
 
     if (ctx->len + diff >= MAX_STR_SIZE) {
@@ -269,7 +260,7 @@ static int complete_line_helper(ToxWindow *self, Toxic *toxic, const char *const
     return diff;
 }
 
-static const char *color_list[] = {
+static const char *const color_list[] = {
     "black",
     "blue",
     "brown",
@@ -284,14 +275,14 @@ static const char *color_list[] = {
     "yellow",
 };
 
-static const char *game_list[] = {
+static const char *const game_list[] = {
     "centipede",
     "chess",
     "life",
     "snake",
 };
 
-static const char *status_list[] = {
+static const char *const status_list[] = {
     "away",
     "busy",
     "online",
@@ -340,18 +331,19 @@ static int complete_path(ToxWindow *self, Toxic *toxic, const char *const *list,
 }
 
 /* Transforms a tab complete starting with the shorthand "~" into the full home directory. */
-static void complete_home_dir(ToxWindow *self, char *path, int pathsize, const char *cmd, int cmdlen)
+static void complete_home_dir(ToxWindow *self, const Paths *paths, char *path, int pathsize,
+                              const char *cmd, int cmdlen)
 {
     ChatContext *ctx = self->chatwin;
 
-    char homedir[MAX_STR_SIZE] = {0};
-    get_home_dir(homedir, sizeof(homedir));
+    char homedir[TOXIC_MAX_PATH_LENGTH] = {0};
+    get_home_dir(paths, homedir, sizeof(homedir));
 
-    char newline[MAX_STR_SIZE + 1];
+    char newline[MAX_STR_SIZE + TOXIC_MAX_PATH_LENGTH];
     snprintf(newline, sizeof(newline), "%s %s%s", cmd, homedir, path + 1);
     snprintf(path, pathsize, "%s", &newline[cmdlen - 1]);
 
-    wchar_t wline[MAX_STR_SIZE];
+    wchar_t wline[MAX_STR_SIZE + TOXIC_MAX_PATH_LENGTH];
 
     if (mbs_to_wcs_buf(wline, newline, sizeof(wline) / sizeof(wchar_t)) == -1) {
         return;
@@ -389,8 +381,8 @@ static bool is_partial_match(const char *s, const char *p, size_t p_len)
 #define MAX_DIRS 75
 int dir_match(ToxWindow *self, Toxic *toxic, const wchar_t *line, const wchar_t *cmd)
 {
-    char b_path[MAX_STR_SIZE + 1];
-    char b_name[MAX_STR_SIZE + 1];
+    char b_path[TOXIC_MAX_PATH_LENGTH + 1];
+    char b_name[TOXIC_MAX_PATH_LENGTH + 1];
     char b_cmd[MAX_STR_SIZE];
     const wchar_t *tmpline = &line[wcslen(cmd) + 1];   /* start after "/command " */
 
@@ -403,7 +395,7 @@ int dir_match(ToxWindow *self, Toxic *toxic, const wchar_t *line, const wchar_t
     }
 
     if (b_path[0] == '~') {
-        complete_home_dir(self, b_path, sizeof(b_path) - 1, b_cmd, strlen(b_cmd) + 2);
+        complete_home_dir(self, toxic->paths, b_path, sizeof(b_path) - 1, b_cmd, strlen(b_cmd) + 2);
     }
 
     int si = char_rfind(b_path, '/', strlen(b_path));
