@@ -1,6 +1,6 @@
 /*  conference.c
  *
- *  Copyright (C) 2014-2024 Toxic All Rights Reserved.
+ *  Copyright (C) 2014-2026 Toxic All Rights Reserved.
  *
  *  This file is part of Toxic. Toxic is free software licensed
  *  under the GNU General Public License 3.0.
@@ -37,6 +37,7 @@
 #include "autocomplete.h"
 #include "conference.h"
 #include "execute.h"
+#include "friendlist.h"
 #include "help.h"
 #include "input.h"
 #include "line_info.h"
@@ -67,14 +68,15 @@ static const char *const conference_cmd_list[] = {
 #endif
     "/avatar",
     "/chatid",
+    "/cinvite",
     "/clear",
     "/close",
     "/color",
+    "/conference",
     "/connect",
     "/decline",
     "/exit",
     "/group",
-    "/conference",
 #ifdef GAMES
     "/game",
 #endif
@@ -168,7 +170,8 @@ static void init_conference_logging(ToxWindow *self, Toxic *toxic, uint32_t conf
     char conference_id[TOX_CONFERENCE_ID_SIZE];
     tox_conference_get_id(tox, conferencenum, (uint8_t *) conference_id);
 
-    if (log_init(ctx->log, c_config, conferences[self->num].title, my_id, conference_id, LOG_TYPE_CHAT) != 0) {
+    if (log_init(ctx->log, c_config, toxic->paths, conferences[self->num].title,
+                 my_id, conference_id, LOG_TYPE_CHAT) != 0) {
         line_info_add(self, c_config, false, NULL, NULL, SYS_MSG, 0, 0, "Warning: Log failed to initialize.");
         return;
     }
@@ -321,7 +324,7 @@ void conference_rename_log_path(Toxic *toxic, uint32_t conferencenum, const char
     char conference_id[TOX_CONFERENCE_ID_SIZE];
     tox_conference_get_id(toxic->tox, conferencenum, (uint8_t *) conference_id);
 
-    if (rename_logfile(toxic->windows, toxic->c_config, chat->title, new_title, myid, conference_id,
+    if (rename_logfile(toxic->windows, toxic->c_config, toxic->paths, chat->title, new_title, myid, conference_id,
                        chat->window_id) != 0) {
         fprintf(stderr, "Failed to rename conference log to '%s'\n", new_title);
     }
@@ -388,7 +391,7 @@ static void conference_onConferenceMessage(ToxWindow *self, Toxic *toxic, uint32
     ChatContext *ctx = self->chatwin;
 
     char nick[TOX_MAX_NAME_LENGTH];
-    get_conference_nick_truncate(tox, nick, peernum, conferencenum);
+    get_conference_nick_truncate(tox, nick, sizeof(nick), peernum, conferencenum);
 
     char selfnick[TOX_MAX_NAME_LENGTH];
     tox_self_get_name(tox, (uint8_t *) selfnick);
@@ -453,7 +456,7 @@ static void conference_onConferenceTitleChange(ToxWindow *self, Toxic *toxic, ui
     }
 
     char nick[TOX_MAX_NAME_LENGTH];
-    get_conference_nick_truncate(tox, nick, peernum, conferencenum);
+    get_conference_nick_truncate(tox, nick, sizeof(nick), peernum, conferencenum);
 
     char tmp_event[MAX_STR_SIZE];
     snprintf(tmp_event, sizeof(tmp_event), "-!- %s set the conference title to: %s", nick, title);
@@ -533,9 +536,7 @@ static void conference_update_name_list(uint32_t conferencenum)
         return;
     }
 
-    if (chat->name_list) {
-        free(chat->name_list);
-    }
+    free(chat->name_list);
 
     chat->name_list = malloc(chat->num_peers * sizeof(NameListEntry));
 
@@ -662,6 +663,7 @@ static void set_peer_audio_position(Tox *tox, uint32_t conferencenum, uint32_t p
     const float angle = asinf(peer_posn - (float)(num_posns - 1) / 2);
     set_source_position(peer->audio_out_idx, sinf(angle), cosf(angle), 0);
 }
+
 #endif // AUDIO
 
 
@@ -965,6 +967,19 @@ static bool conference_onKey(ToxWindow *self, Toxic *toxic, wint_t key, bool ltr
                 }
             } else if (wcsncmp(ctx->line, L"/avatar ", wcslen(L"/avatar ")) == 0) {
                 diff = dir_match(self, toxic, ctx->line, L"/avatar");
+            } else if (wcsncmp(ctx->line, L"/cinvite ", wcslen(L"/cinvite ")) == 0) {
+                size_t num_friends = friendlist_get_count(toxic->friends);
+                char **friend_names = (char **) malloc_ptr_array(num_friends, TOX_MAX_NAME_LENGTH);
+
+                if (friend_names != NULL) {
+                    friendlist_get_names(toxic->friends, friend_names, num_friends, TOX_MAX_NAME_LENGTH);
+                    diff = complete_line(self, toxic, (const char *const *) friend_names, num_friends);
+                    free_ptr_array((void **) friend_names);
+                } else {
+                    diff = -1;
+                    num_friends = 0;
+                    fprintf(stderr, "Failed to allocate memory for friends name list\n");
+                }
             }
 
 #ifdef PYTHON
@@ -1026,17 +1041,20 @@ static bool conference_onKey(ToxWindow *self, Toxic *toxic, wint_t key, bool ltr
         input_ret = true;
         rm_trailing_spaces_buf(ctx);
 
-        if (!wstring_is_empty(ctx->line)) {
+        wstrsubst(ctx->line, L'¶', L'\n');
+
+        char line[MAX_STR_SIZE];
+
+        if (wcs_to_mbs_buf(line, ctx->line, MAX_STR_SIZE) == -1) {
+            memset(line, 0, sizeof(line));
+            line_info_add(self, c_config, false, NULL, NULL, SYS_MSG, 0, RED, " * Failed to parse message.");
+        }
+
+        const bool contains_blocked_word = string_contains_blocked_word(line, &toxic->client_data);
+
+        if (line[0] != '\0' && !contains_blocked_word) {
             add_line_to_hist(ctx);
 
-            wstrsubst(ctx->line, L'¶', L'\n');
-
-            char line[MAX_STR_SIZE];
-
-            if (wcs_to_mbs_buf(line, ctx->line, MAX_STR_SIZE) == -1) {
-                memset(line, 0, sizeof(line));
-            }
-
             if (line[0] == '/') {
                 if (strcmp(line, "/close") == 0) {
                     delete_conference(self, toxic, self->num);
@@ -1046,20 +1064,22 @@ static bool conference_onKey(ToxWindow *self, Toxic *toxic, wint_t key, bool ltr
                 } else {
                     execute(ctx->history, self, toxic, line, CONFERENCE_COMMAND_MODE);
                 }
-            } else if (line[0]) {
+            } else {
                 Tox_Err_Conference_Send_Message err;
 
                 if (!tox_conference_send_message(tox, self->num, TOX_MESSAGE_TYPE_NORMAL, (uint8_t *) line, strlen(line), &err)) {
                     line_info_add(self, c_config, false, NULL, NULL, SYS_MSG, 0, RED, " * Failed to send message (error %d)", err);
                 }
-            } else {
-                line_info_add(self, c_config, false, NULL, NULL, SYS_MSG, 0, RED, " * Failed to parse message.");
             }
         }
 
-        wclear(ctx->linewin);
-        wmove(self->window, y2, 0);
-        reset_buf(ctx);
+        if (!contains_blocked_word) {
+            wclear(ctx->linewin);
+            wmove(self->window, y2, 0);
+            reset_buf(ctx);
+        } else {
+            line_info_add(self, c_config, false, NULL, NULL, SYS_MSG, 0, RED, "* Message contains blocked word");
+        }
     }
 
     return input_ret;
@@ -1139,6 +1159,12 @@ static void conference_onDraw(ToxWindow *self, Toxic *toxic)
 
     curs_set(1);
 
+    if (self->x != x2 && !self->scroll_pause) {
+        line_info_reset_start(self, ctx->hst);
+    }
+
+    self->x = x2;
+
     if (ctx->len > 0) {
         mvwprintw(ctx->linewin, 0, 0, "%ls", &ctx->line[ctx->start]);
     }
@@ -1602,4 +1628,5 @@ float conference_get_VAD_threshold(uint32_t conferencenum)
 
     return device_get_VAD_threshold(chat->audio_in_idx);
 }
+
 #endif  // AUDIO
