@@ -1,6 +1,6 @@
 /*  game_base.c
  *
- *  Copyright (C) 2020-2024 Toxic All Rights Reserved.
+ *  Copyright (C) 2020-2026 Toxic All Rights Reserved.
  *
  *  This file is part of Toxic. Toxic is free software licensed
  *  under the GNU General Public License 3.0.
@@ -53,7 +53,7 @@ extern struct Winthread Winthread;
                                                  && ((max_x) >= (GAME_MAX_RECT_X_LARGE)))
 
 
-static ToxWindow *game_new_window(Tox *tox, GameType type, uint32_t friendnumber);
+static ToxWindow *game_new_window(FriendsList *friends, GameType type, uint32_t friendnumber);
 
 struct GameList {
     const char *name;
@@ -252,7 +252,7 @@ int game_initialize(const ToxWindow *parent, Toxic *toxic, GameType type, uint32
 
     max_y -= (CHATBOX_HEIGHT + WINDOW_BAR_HEIGHT);
 
-    ToxWindow *self = game_new_window(toxic->tox, type, parent->num);
+    ToxWindow *self = game_new_window(toxic->friends, type, parent->num);
 
     if (self == NULL) {
         return -4;
@@ -276,7 +276,7 @@ int game_initialize(const ToxWindow *parent, Toxic *toxic, GameType type, uint32
             return -3;
         }
 
-        if (get_friend_connection_status(parent->num) == TOX_CONNECTION_NONE) {
+        if (get_friend_connection_status(toxic->friends, parent->num) == TOX_CONNECTION_NONE) {
             game_init_abort(parent, self, toxic->windows, c_config);
             return -2;
         }
@@ -886,7 +886,7 @@ static void game_onPacket(ToxWindow *self, Toxic *toxic, uint32_t friendnumber,
     }
 }
 
-static ToxWindow *game_new_window(Tox *tox, GameType type, uint32_t friendnumber)
+static ToxWindow *game_new_window(FriendsList *friends, GameType type, uint32_t friendnumber)
 {
     const char *window_name = game_get_name_string(type);
 
@@ -919,16 +919,13 @@ static ToxWindow *game_new_window(Tox *tox, GameType type, uint32_t friendnumber
 
     if (game_type_is_multi_only(type)) {
         char name[TOXIC_MAX_NAME_LENGTH + 1];
-        get_friend_name(name, sizeof(name), friendnumber);
+        get_friend_name(friends, name, sizeof(name), friendnumber);
 
         char buf[sizeof(name) + sizeof(ret->name) + 4];
         snprintf(buf, sizeof(buf), "%s (%s)", window_name, name);
 
-        const size_t name_size = sizeof(ret->name);
-
-        buf[name_size - 1] = '\0';
-
-        snprintf(ret->name, name_size, "%s", buf);
+        const size_t title_size = MIN(strlen(buf) + 1, sizeof(ret->name));
+        snprintf(ret->name, title_size, "%s", buf);
     } else {
         snprintf(ret->name, sizeof(ret->name), "%s", window_name);
     }
