@@ -1,6 +1,6 @@
 /*  osx_video.h
  *
- *  Copyright (C) 2014-2024 Toxic All Rights Reserved.
+ *  Copyright (C) 2014-2026 Toxic All Rights Reserved.
  *
  *  This file is part of Toxic. Toxic is free software licensed
  *  under the GNU General Public License 3.0.
@@ -12,21 +12,20 @@
 #include <netinet/in.h>
 
 #ifdef __OBJC__
-#import <Foundation/Foundation.h>
 #import <AVFoundation/AVFoundation.h>
+#import <Foundation/Foundation.h>
 #endif /* __OBJC__ */
 
-#define RELEASE_CHK(func, obj) if ((obj))\
-    func((obj));
+#define RELEASE_CHK(func, obj) \
+    if ((obj))                 \
+        func((obj));
 
-void bgrtoyuv420(uint8_t *plane_y, uint8_t *plane_u, uint8_t *plane_v, uint8_t *rgb, uint16_t width, uint16_t height);
+void bgrtoyuv420(uint8_t *plane_y, uint8_t *plane_u, uint8_t *plane_v, uint8_t *rgb, uint16_t width,
+    uint16_t height);
 
 #ifdef __OBJC__
-@interface OSXVideo :
-    NSObject <AVCaptureVideoDataOutputSampleBufferDelegate>
-- (instancetype)initWithDeviceNames:
-    (char **)device_names AmtDevices:
-    (int *)size;
+@interface OSXVideo : NSObject <AVCaptureVideoDataOutputSampleBufferDelegate>
+- (instancetype)initWithDeviceNames:(char **)device_names AmtDevices:(int *)size;
 @end
 #endif /* __OBJC__ */
 
@@ -39,5 +38,4 @@ void osx_video_close_device(uint32_t device_idx);
 /* Read data from device */
 int osx_video_read_device(uint8_t *y, uint8_t *u, uint8_t *v, uint16_t *width, uint16_t *height);
 
-
 #endif /* OSX_VIDEO_H */
